<script setup>
import facilityApi from "@/api/facility/index";
import setPostParams from "@/utils/searchParams.js";
import {onMounted} from "vue";

const route = useRoute();
const {proxy} = getCurrentInstance();
const imgBaseUrl = import.meta.env.VITE_APP_IMG_BASEURL //图片前缀

/**
 * 搜索相关
 */
/** 搜索按钮操作 */
function handleQuery() {
    getList(searchParams.value)
}

/** 重置按钮操作 */
function resetQuery() {
    proxy.resetForm("queryRef");
    handleQuery();
}

/**
 *  Table表格权限数据列表相关
 */
const pageParam = ref({
    total: 0,
    limit: 0,
    page: 1,
})
const tableData = ref([]);
const inpTip = '请输入', selTip = '请选择';
let tableHeader = ref({
    facilityCode: '设备编号',
    facilityName: '设备名称',
    longitude: '经度',
    latitude: '纬度',
    facilityUrl: '设备图片',
    address: '设备地址',
    installDate: '安装日期',
})

/** 获取权限列表 */
async function getList(val) {
    let postParam = setPostParams(val)
    await facilityApi().search(postParam).then((res) => {
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
}

/**
 *  表单相关
 */
const formLabel = ({
    facilityCode: '设备编号',
    facilityName: '设备名称',
    longitude: '经度',
    latitude: '纬度',
    facilityUrl: '设备图片',
    address: '设备地址',
    installDate: '安装时间'
})
const rules = ref({
    facilityCode: [{required: true, message: `${inpTip + formLabel.facilityCode}`, trigger: "blur"}],
    facilityName: [{required: true, message: `${inpTip + formLabel.facilityName}`, trigger: "blur"}],
    longitude: [{required: true, message: `${inpTip + formLabel.longitude}`, trigger: "blur"}],
    latitude: [{required: true, message: `${inpTip + formLabel.latitude}`, trigger: "blur"}],
    address: [{required: true, message: `${inpTip + formLabel.address}`, trigger: "blur"}],
});
const form = ref({});
const searchParams = ref({
    keywords: '',
});

/** 新增按钮操作 */
async function handleAdd() {
    reset();
    open.value = true;
    isDetail.value = false;
    title.value = "新增";
}

/** 修改按钮操作 */
async function handleUpdate(row) {
    reset();
    Object.keys(row).forEach(key => {
        if (form.value.hasOwnProperty(key)) {
            form.value[key] = row[key];
        }
    });
    form.value.id = row.id
    open.value = true;
    isDetail.value = true;
    title.value = "修改";
}

/** 删除按钮操作 */
function handleDelete(row) {
    proxy.$modal.confirm('是否确认删除名称为"' + row.contact + '"的数据项?').then(function () {
        return facilityApi().remove(row.id);
    }).then(() => {
        getList();
        proxy.$modal.msgSuccess("删除成功");
    }).catch(() => {
    });
}


/**
 *  新增/修改弹窗Form表单相关
 */
//设备参数弹窗
const open = ref(false);
const title = ref("");
const isDetail = ref(false);

//上传文件，添加图片地址信息
const uploadData = (data) => {
    form.value.facilityUrl = data.toString();
}

/** 提交按钮 */
function submitForm() {
    proxy.$refs["facilityTypeRef"].validate(valid => {
        if (valid) {
            // form.value.contactPhone = Number(form.value.contactPhone)

            if (form.value.id != undefined) {
                facilityApi().modify(form.value).then(res => {
                    proxy.$modal.msgSuccess("修改成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("修改失败");
                });
            } else {
                facilityApi().create(form.value).then(res => {
                    proxy.$modal.msgSuccess("新增成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("新增失败");
                });
                ;
            }
        }
    });
}

/** 取消按钮 */
function cancel() {
    open.value = false;
    reset();
}

/** 表单重置 */
function reset() {
    form.value = {
        facilityCode: '',
        facilityName: '',
        longitude: '',
        latitude: '',
        facilityUrl: '',
        address: '',
        installDate: ''
    };
    proxy.resetForm("facilityTypeRef");
}

onMounted(() => {
    getList();
})

</script>
<template>
    <div class="app-container">
        <el-form :model="searchParams" ref="queryRef" :inline="true">
            <el-form-item label="" prop="keywords">
                <el-input
                    v-model="searchParams.keywords"
                    placeholder="请输入搜索信息"
                    clearable
                    style="width: 200px"
                    @keyup.enter="handleQuery"
                />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
                <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                    type="primary"
                    plain
                    icon="Plus"
                    @click="handleAdd"
                >新增
                </el-button>
            </el-col>
        </el-row>
        <!--表格及分页-->
        <el-table :data="tableData">
            <el-table-column
                v-for="(item, key, index) of tableHeader"
                :prop="key.toString()"
                :label="item"
                :key="index"
                align="center"
            >
                <template #default="scope">
                    <div v-if="key.toString() === 'facilityUrl'" style="height: 50px;margin: 0 auto">
                        <img :src="imgBaseUrl + scope.row.facilityUrl" class="table-headImg" alt=""/>
                    </div>
                </template>
            </el-table-column>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template #default="scope">
                    <el-button link type="primary" icon="Edit" v-has="['update',route]"
                               @click="handleUpdate(scope.row)">修改
                    </el-button>
                    <el-button link type="primary" icon="Delete" v-has="['delete',route]"
                               @click="handleDelete(scope.row)">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>
        <pagination
            :total="pageParam.total"
            v-model:page="pageParam.page"
            v-model:limit="pageParam.limit"
            :page-sizes="[10,20,30]"
            @pagination="getList"
        />
        <!-- 添加/修改表单 -->
        <el-dialog :title="title" v-model="open" append-to-body center>
            <el-form class="form-box" ref="facilityTypeRef" :model="form" :rules="rules" label-width='auto'>
                <el-form-item :label="formLabel.facilityCode" prop="facilityCode">
                    <el-input v-model="form.facilityCode" :placeholder="inpTip+formLabel.facilityCode"/>
                </el-form-item>
                <el-form-item :label="formLabel.facilityName" prop="facilityName">
                    <el-input v-model="form.facilityName" :placeholder="inpTip+formLabel.facilityName"/>
                </el-form-item>
                <el-form-item :label="formLabel.longitude" prop="longitude">
                    <el-input v-model="form.longitude" :placeholder="inpTip+formLabel.longitude"/>
                </el-form-item>
                <el-form-item :label="formLabel.latitude" prop="latitude">
                    <el-input v-model="form.latitude" :placeholder="inpTip+formLabel.latitude"/>
                </el-form-item>
                <el-form-item :label="formLabel.address" prop="address">
                    <el-input v-model="form.address" :placeholder="inpTip+formLabel.address"/>
                </el-form-item>
                <el-form-item label="安装日期" prop="installDate">
                    <el-date-picker
                        v-model="form.installDate"
                        type="date"
                        placeholder="请选择安装日期"
                        format="YYYY-MM-DD"
                        value-format="YYYY-MM-DD"
                        :disabled="isDetail ? true : false"
                    />
                </el-form-item>
                <el-form-item label="资料上传" prop="facilityUrl" style="flex: 1">
                    <upload-icons @uploadData="uploadData" :imageList="form.facilityUrl" :limit="1"></upload-icons>
                    <span style="display: block;">(请上传1张设备图片)</span>
                </el-form-item>
            </el-form>
            <template #footer>
                <div class="dialog-footer">
                    <el-button type="primary" @click="submitForm">确 定</el-button>
                    <el-button @click="cancel">取 消</el-button>
                </div>
            </template>
        </el-dialog>
    </div>
</template>

<style lang="scss" scoped>
.table-headImg {
    max-width: 100px;
    height: 50px;
}

.form-box {
    justify-content: normal;

    :deep(.el-cascader) {
        flex-grow: 1;
    }
}
</style>
 